Index: runtime/vm/stub_code_mips.cc |
diff --git a/runtime/vm/stub_code_mips.cc b/runtime/vm/stub_code_mips.cc |
index d93cb8bd5d3184c10894ff8c0bed53b24e9e2c67..c2336441e835d7c98ba0e7849099b79800e93605 100644 |
--- a/runtime/vm/stub_code_mips.cc |
+++ b/runtime/vm/stub_code_mips.cc |
@@ -1882,11 +1882,12 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) { |
Label loop, found, not_found, next_iteration; |
// T0: instance class id. |
// T1: instance type arguments. |
// T2: Entry start. |
// T7: null. |
__ SmiTag(T0); |
__ BranchNotEqual(T0, Immediate(Smi::RawValue(kClosureCid)), &loop); |
+ __ lw(T1, FieldAddress(A0, Closure::instantiator_offset())); |
__ lw(T0, FieldAddress(A0, Closure::function_offset())); |
// T0: instance class id as Smi or function. |
__ Bind(&loop); |
@@ -1882,11 +1882,12 @@ static void GenerateSubtypeNTestCacheStub(Assembler* assembler, int n) { |
Label loop, found, not_found, next_iteration; |
// T0: instance class id. |
- // T1: instance type arguments. |
+ // T1: instance type arguments (still null if closure). |
// T2: Entry start. |
// T7: null. |